@@ -9,6 +9,7 @@ from fast_tracker import Layer, ComponentType
 from fast_tracker.trace import tags
 from fast_tracker.trace.context import get_context
 from fast_tracker.trace.tags import Tag
+from fast_tracker.utils import functions
 
 
 def install():
@@ -26,9 +27,11 @@ def install():
             res = _execute(this, query, args)
 
             span.tag(Tag(key=tags.DbType, val="mysql"))
-            span.tag(Tag(key=tags.DbInstance, val=(this.connection.db or b"").decode("utf-8")))
+            span.tag(Tag(key=tags.DbInstance, val=(this.connection.db or b'').decode("utf-8")))
             span.tag(Tag(key=tags.DbStatement, val=query))
 
+            functions.log("mysql span is: %r", span)
+
             return res
 
     Cursor.execute = _fast_execute
